@@ -152,8 +152,7 @@ static const uint32_t cal_GetPropsList[] = {
 
 static const uint32_t cal_IDList[] = {
 	PR_FID, 
-	PR_MID,
-	PR_LAST_MODIFICATION_TIME
+	PR_MID
 };
 
 G_END_DECLS
